# Class: USB&#95;group

A group of compatible USBs across the resource pool

## Fields for class: USB&#95;group

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`name_description`  |`string`            |_RW_           |a notes field containing human&#45;readable description|
|`name_label`        |`string`            |_RW_           |a human&#45;readable name               |
|`other_config`      |`(string -> string) map`|_RW_           |Additional configuration                |
|`PUSBs`             |`PUSB ref set`      |_RO/runtime_   |List of PUSBs in the group              |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VUSBs`             |`VUSB ref set`      |_RO/runtime_   |List of VUSBs using the group           |

## RPCs associated with class: USB&#95;group

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given USB&#95;group.

_Signature:_

```
void add_to_other_config (session ref session_ref, USB_group ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: create

_Overview:_

_Signature:_

```
USB_group ref create (session ref session_ref, string name_label, string name_description, (string -> string) map other_config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`name_label`                  |                                        |
|`string`                      |`name_description`            |                                        |
|`(string -> string) map`      |`other_config`                |                                        |

_Minimum Role:_ pool-admin

_Return Type:_ `USB_group ref`

The reference of the created USB&#95;group

### RPC name: destroy

_Overview:_

_Signature:_

```
void destroy (session ref session_ref, USB_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |The USB group to destroy                |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the USB&#95;groups known to the system.

_Signature:_

```
USB_group ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of USB&#95;group references to USB&#95;group records for all USB&#95;groups known to the system.

_Signature:_

```
(USB_group ref -> USB_group record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(USB_group ref -> USB_group record) map`

records of all objects

### RPC name: get&#95;by&#95;name&#95;label

_Overview:_

Get all the USB&#95;group instances with the given label.

_Signature:_

```
USB_group ref set get_by_name_label (session ref session_ref, string label)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`label`                       |label of object to return               |

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref set`

references to objects with matching names

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the USB&#95;group instance with the specified UUID.

_Signature:_

```
USB_group ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref`

reference to the object

### RPC name: get&#95;name&#95;description

_Overview:_

Get the name/description field of the given USB&#95;group.

_Signature:_

```
string get_name_description (session ref session_ref, USB_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;name&#95;label

_Overview:_

Get the name/label field of the given USB&#95;group.

_Signature:_

```
string get_name_label (session ref session_ref, USB_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given USB&#95;group.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, USB_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;PUSBs

_Overview:_

Get the PUSBs field of the given USB&#95;group.

_Signature:_

```
PUSB ref set get_PUSBs (session ref session_ref, USB_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `PUSB ref set`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given USB&#95;group.

_Signature:_

```
USB_group record get_record (session ref session_ref, USB_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `USB_group record`

all fields from the object

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given USB&#95;group.

_Signature:_

```
string get_uuid (session ref session_ref, USB_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VUSBs

_Overview:_

Get the VUSBs field of the given USB&#95;group.

_Signature:_

```
VUSB ref set get_VUSBs (session ref session_ref, USB_group ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VUSB ref set`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given USB&#95;group.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, USB_group ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;name&#95;description

_Overview:_

Set the name/description field of the given USB&#95;group.

_Signature:_

```
void set_name_description (session ref session_ref, USB_group ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;name&#95;label

_Overview:_

Set the name/label field of the given USB&#95;group.

_Signature:_

```
void set_name_label (session ref session_ref, USB_group ref self, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |
|`string`                      |`value`                       |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given USB&#95;group.

_Signature:_

```
void set_other_config (session ref session_ref, USB_group ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`USB_group ref`               |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`
