# Class: VUSB

Describes the vusb device

## Fields for class: VUSB

|Field               |Type                |Qualifier      |Description                             |
|:-------------------|:-------------------|:--------------|:---------------------------------------|
|`allowed_operations`|`vusb_operations set`|_RO/runtime_   |list of the operations allowed in this state. This list is advisory only and the server state may have changed by the time this field is read by a client.|
|`current_operations`|`(string -> vusb_operations) map`|_RO/runtime_   |links each of the running tasks using this object &#40;by reference&#41; to a current&#95;operation enum which describes the nature of the task.|
|`currently_attached`|`bool`              |_RO/runtime_   |is the device currently attached        |
|`other_config`      |`(string -> string) map`|_RW_           |Additional configuration                |
|`USB_group`         |`USB_group ref`     |_RO/runtime_   |USB group used by the VUSB              |
|`uuid`              |`string`            |_RO/runtime_   |Unique identifier/object reference      |
|`VM`                |`VM ref`            |_RO/runtime_   |VM that owns the VUSB                   |

## RPCs associated with class: VUSB

### RPC name: add&#95;to&#95;other&#95;config

_Overview:_

Add the given key&#45;value pair to the other&#95;config field of the given VUSB.

_Signature:_

```
void add_to_other_config (session ref session_ref, VUSB ref self, string key, string value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to add                              |
|`string`                      |`value`                       |Value to add                            |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: create

_Overview:_

Create a new VUSB record in the database only

_Signature:_

```
VUSB ref create (session ref session_ref, VM ref VM, USB_group ref USB_group, (string -> string) map other_config)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VM ref`                      |`VM`                          |The VM                                  |
|`USB_group ref`               |`USB_group`                   |                                        |
|`(string -> string) map`      |`other_config`                |                                        |

_Minimum Role:_ pool-admin

_Return Type:_ `VUSB ref`

The ref of the newly created VUSB record.

### RPC name: destroy

_Overview:_

Removes a VUSB record from the database

_Signature:_

```
void destroy (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |The VUSB to destroy about               |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: get&#95;all

_Overview:_

Return a list of all the VUSBs known to the system.

_Signature:_

```
VUSB ref set get_all (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `VUSB ref set`

references to all objects

### RPC name: get&#95;all&#95;records

_Overview:_

Return a map of VUSB references to VUSB records for all VUSBs known to the system.

_Signature:_

```
(VUSB ref -> VUSB record) map get_all_records (session ref session_ref)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |

_Minimum Role:_ read-only

_Return Type:_ `(VUSB ref -> VUSB record) map`

records of all objects

### RPC name: get&#95;allowed&#95;operations

_Overview:_

Get the allowed&#95;operations field of the given VUSB.

_Signature:_

```
vusb_operations set get_allowed_operations (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `vusb_operations set`

value of the field

### RPC name: get&#95;by&#95;uuid

_Overview:_

Get a reference to the VUSB instance with the specified UUID.

_Signature:_

```
VUSB ref get_by_uuid (session ref session_ref, string uuid)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`string`                      |`uuid`                        |UUID of object to return                |

_Minimum Role:_ read-only

_Return Type:_ `VUSB ref`

reference to the object

### RPC name: get&#95;current&#95;operations

_Overview:_

Get the current&#95;operations field of the given VUSB.

_Signature:_

```
(string -> vusb_operations) map get_current_operations (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> vusb_operations) map`

value of the field

### RPC name: get&#95;currently&#95;attached

_Overview:_

Get the currently&#95;attached field of the given VUSB.

_Signature:_

```
bool get_currently_attached (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `bool`

value of the field

### RPC name: get&#95;other&#95;config

_Overview:_

Get the other&#95;config field of the given VUSB.

_Signature:_

```
(string -> string) map get_other_config (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `(string -> string) map`

value of the field

### RPC name: get&#95;record

_Overview:_

Get a record containing the current state of the given VUSB.

_Signature:_

```
VUSB record get_record (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VUSB record`

all fields from the object

### RPC name: get&#95;USB&#95;group

_Overview:_

Get the USB&#95;group field of the given VUSB.

_Signature:_

```
USB_group ref get_USB_group (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `USB_group ref`

value of the field

### RPC name: get&#95;uuid

_Overview:_

Get the uuid field of the given VUSB.

_Signature:_

```
string get_uuid (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `string`

value of the field

### RPC name: get&#95;VM

_Overview:_

Get the VM field of the given VUSB.

_Signature:_

```
VM ref get_VM (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |

_Minimum Role:_ read-only

_Return Type:_ `VM ref`

value of the field

### RPC name: remove&#95;from&#95;other&#95;config

_Overview:_

Remove the given key and its corresponding value from the other&#95;config field of the given VUSB.  If the key is not in that Map, then do nothing.

_Signature:_

```
void remove_from_other_config (session ref session_ref, VUSB ref self, string key)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |
|`string`                      |`key`                         |Key to remove                           |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: set&#95;other&#95;config

_Overview:_

Set the other&#95;config field of the given VUSB.

_Signature:_

```
void set_other_config (session ref session_ref, VUSB ref self, (string -> string) map value)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |reference to the object                 |
|`(string -> string) map`      |`value`                       |New value to set                        |

_Minimum Role:_ pool-admin

_Return Type:_ `void`

### RPC name: unplug

_Overview:_

Unplug the vusb device from the vm.

_Signature:_

```
void unplug (session ref session_ref, VUSB ref self)
```

_Arguments:_

|Type                          |Name                          |Description                             |
|:-----------------------------|:-----------------------------|:---------------------------------------|
|`session ref`                 |`session_ref`                 |Reference to a valid session            |
|`VUSB ref`                    |`self`                        |vusb deivce                             |

_Minimum Role:_ pool-admin

_Return Type:_ `void`
